@@ -7,15 +7,20 @@ from .run_cmd1 import run_cmd1  # noqa: F401
 from .gen_keypair import gen_keypair  # noqa: F401
 from .setup_git import setup_git  # noqa: F401
 from .setup_ssh_tunnel import setup_ssh_tunnel  # noqa: F401
+from .check_running import check_running  # noqa: F401
+from .config import Settings  # noqa: F401
 
-__version__ = "0.1.2"
+__version__ = "0.1.4"
 
 __all__ = (
     "create_file",
     "append_content",
     "chmod600",
     "run_cmd",
+    "run_cmd1",
     "gen_keypair",
     "setup_git",
     "setup_ssh_tunnel",
+    "check_running",
+    "Settings",
 )
